cordova.define("cordova-plugin-admob-tomitank.AdMob", function(require, exports, module) {
'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var exec$1 = _interopDefault(require('cordova/exec'));

function _typeof(obj) {
  "@babel/helpers - typeof";

  if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
    _typeof = function (obj) {
      return typeof obj;
    };
  } else {
    _typeof = function (obj) {
      return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
    };
  }

  return _typeof(obj);
}

function _classCallCheck(instance, Constructor) {
  if (!(instance instanceof Constructor)) {
    throw new TypeError("Cannot call a class as a function");
  }
}

function _defineProperties(target, props) {
  for (var i = 0; i < props.length; i++) {
    var descriptor = props[i];
    descriptor.enumerable = descriptor.enumerable || false;
    descriptor.configurable = true;
    if ("value" in descriptor) descriptor.writable = true;
    Object.defineProperty(target, descriptor.key, descriptor);
  }
}

function _createClass(Constructor, protoProps, staticProps) {
  if (protoProps) _defineProperties(Constructor.prototype, protoProps);
  if (staticProps) _defineProperties(Constructor, staticProps);
  return Constructor;
}

function _defineProperty(obj, key, value) {
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }

  return obj;
}

function ownKeys(object, enumerableOnly) {
  var keys = Object.keys(object);

  if (Object.getOwnPropertySymbols) {
    var symbols = Object.getOwnPropertySymbols(object);
    if (enumerableOnly) symbols = symbols.filter(function (sym) {
      return Object.getOwnPropertyDescriptor(object, sym).enumerable;
    });
    keys.push.apply(keys, symbols);
  }

  return keys;
}

function _objectSpread2(target) {
  for (var i = 1; i < arguments.length; i++) {
    var source = arguments[i] != null ? arguments[i] : {};

    if (i % 2) {
      ownKeys(Object(source), true).forEach(function (key) {
        _defineProperty(target, key, source[key]);
      });
    } else if (Object.getOwnPropertyDescriptors) {
      Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
    } else {
      ownKeys(Object(source)).forEach(function (key) {
        Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
      });
    }
  }

  return target;
}

/**
 * Checks if `value` is `undefined`.
 *
 * @static
 * @since 0.1.0
 * @memberOf _
 * @category Lang
 * @param {*} value The value to check.
 * @returns {boolean} Returns `true` if `value` is `undefined`, else `false`.
 * @example
 *
 * _.isUndefined(void 0);
 * // => true
 *
 * _.isUndefined(null);
 * // => false
 */
function isUndefined(value) {
  return value === undefined;
}

/**
 * Base config object.
 * @typedef {Object} BaseConfig
 * @property {string} [id=TESTING_AD_ID] - Ad Unit ID
 * @property {boolean} [isTesting=false] - Receiving test ad
 * @property {boolean} [autoShow=true] - Auto show ad when loaded
 *
 * @property {boolean|null} [forChild=null]
 * Child-directed setting.
 * Default is not calling `tagForChildDirectedTreatment`.
 * Set to `true` for `tagForChildDirectedTreatment(true)`.
 * Set to `false` for `tagForChildDirectedTreatment(false)`.
 * @see https://firebase.google.com/docs/admob/android/targeting#child-directed_setting
 *
 * @property {boolean|null} [forFamily=null]
 * Designed for Families setting.
 * Android-only.
 * Default is not calling `setIsDesignedForFamilies`.
 * Set to `true` for `setIsDesignedForFamilies(true)`.
 * Set to `false` for `setIsDesignedForFamilies(false)`.
 * @see https://firebase.google.com/docs/admob/android/targeting#designed_for_families_setting
 *
 * @property {Array<number>|null} [location=null]
 * Location targeting.
 * It accept an array in the form of `[latitude, longitude]`.
 * Android-only.
 * Default is not calling `setLatitude` and `setLongitude`.
 */

/**
 * @ignore
 */

function exec(method, args) {
  return new Promise(function (resolve, reject) {
    exec$1(resolve, reject, 'AdMob', method, args);
  });
}

function isString(x) {
  return typeof x === 'string';
}

function boolean2string(x) {
  if (x === null) {
    return '';
  }

  if (x === true) {
    return 'yes';
  }

  if (x === false) {
    return 'no';
  }

  return x;
}
/**
 * @ignore
 */


function translateOptions(options) {
  /* eslint-disable no-console */
  var opts = {};

  if (!isUndefined(options.forChild)) {
    opts.forChild = boolean2string(options.forChild);

    if (isString(options.forChild)) {
      console.warn('`forChild` will not accept string in future, pass boolean instead');
    }
  }

  if (!isUndefined(options.forFamily)) {
    opts.forFamily = boolean2string(options.forFamily);

    if (isString(options.forFamily)) {
      console.warn('`forFamily` will not accept string in future, pass boolean instead');
    }
  }
  /* eslint-enable no-console */


  return _objectSpread2(_objectSpread2(_objectSpread2({}, options), opts), {}, {
    // TODO update native implementation using `size`
    adSize: options.size
  });
}
/**
 * @ignore
 */

function buildEvents(adType, eventKeys) {
  return eventKeys.reduce(function (acc, eventKey) {
    acc[eventKey] = "admob.".concat(adType, ".events.").concat(eventKey);
    return acc;
  }, {});
}

/**
 * Banner config object.
 * @typedef {BaseConfig} BannerConfig
 * @property {boolean} [bannerAtTop=false]
 * set to true, to put banner at top
 * @property {boolean} [overlap=true]
 * set to true, to allow banner overlap webview
 * @property {boolean} [offsetTopBar=false]
 * set to true to avoid ios7 status bar overlap
 * @property {string} [size=SMART_BANNER] - {@link BANNER_SIZE}
 */

var events = buildEvents('banner', ['LOAD', 'LOAD_FAIL', 'OPEN', 'CLOSE']);
/**
 * @typedef {Object} BANNER_SIZE
 * @property {string} FLUID - FLUID
 * @property {string} BANNER - BANNER
 * @property {string} IAB_MRECT - IAB_MRECT
 * @property {string} IAB_BANNER - IAB_BANNER
 * @property {string} LARGE_BANNER - LARGE_BANNER
 * @property {string} SMART_BANNER - SMART_BANNER
 * @property {string} IAB_LEADERBOARD - IAB_LEADERBOARD
 */

/**
 * @constant
 * @type {Object}
 */

var sizes = {
  FLUID: 'FLUID',
  BANNER: 'BANNER',
  IAB_MRECT: 'IAB_MRECT',
  IAB_BANNER: 'IAB_BANNER',
  LARGE_BANNER: 'LARGE_BANNER',
  SMART_BANNER: 'SMART_BANNER',
  IAB_LEADERBOARD: 'IAB_LEADERBOARD',
  // android-only
  SEARCH: 'SEARCH',
  FULL_BANNER: 'FULL_BANNER',
  LEADERBOARD: 'LEADERBOARD',
  WIDE_SKYSCRAPER: 'WIDE_SKYSCRAPER',
  MEDIUM_RECTANGLE: 'MEDIUM_RECTANGLE'
};
/**
 * @protected
 * @desc
 * See usage in {@link banner}.
 */

var Banner = /*#__PURE__*/function () {
  /**
   * Banner sizes
   * @type {BANNER_SIZE}
   */

  /**
   * @protected
   * @param {BannerConfig} opts - Initial config.
   */
  function Banner(opts) {
    _classCallCheck(this, Banner);

    this.config(_objectSpread2({
      size: sizes.SMART_BANNER
    }, opts));
  }
  /**
   * Update config.
   *
   * @param {BannerConfig} opts - New config.
   * @returns {BannerConfig} Updated config.
   */


  _createClass(Banner, [{
    key: "config",
    value: function config(opts) {
      this._config = _objectSpread2(_objectSpread2({}, this._config), opts);
      return this._config;
    }
    /**
     * Create banner.
     *
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "prepare",
    value: function prepare() {
      var options = _objectSpread2({
        publisherId: this._config.id
      }, this._config);

      delete options.id;
      return exec('createBannerView', [translateOptions(options)]);
    }
    /**
     * Show the banner.
     *
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "show",
    value: function show() {
      return exec('showAd', [true]);
    }
    /**
     * Hide the banner.
     *
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "hide",
    value: function hide() {
      return exec('showAd', [false]);
    }
    /**
     * Remove the banner.
     *
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "remove",
    value: function remove() {
      return exec('destroyBannerView', []);
    }
  }]);

  return Banner;
}();

_defineProperty(Banner, "events", events);

_defineProperty(Banner, "sizes", sizes);

/**
 * Interstitial config object.
 * @typedef {BaseConfig} InterstitialConfig
 */

var events$1 = buildEvents('interstitial', ['LOAD', 'LOAD_FAIL', 'OPEN', 'CLOSE']);
/**
 * @protected
 * @desc
 * See usage in {@link interstitial}.
 */

var Interstitial = /*#__PURE__*/function () {
  /**
   * @protected
   * @param {InterstitialConfig} opts - Initial config.
   */
  function Interstitial(opts) {
    _classCallCheck(this, Interstitial);

    this.config(_objectSpread2({}, opts));
  }
  /**
   * Update config.
   *
   * @param {InterstitialConfig} opts - New config.
   * @returns {InterstitialConfig} Updated config.
   */


  _createClass(Interstitial, [{
    key: "config",
    value: function config(opts) {
      this._config = _objectSpread2(_objectSpread2({}, this._config), opts);
      return this._config;
    }
    /**
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "prepare",
    value: function prepare() {
      var options = _objectSpread2({
        interstitialAdId: this._config.id
      }, this._config);

      delete options.id;
      return exec('prepareInterstitial', [translateOptions(options)]);
    }
    /**
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "show",
    value: function show() {
      return exec('showInterstitialAd', [true]);
    }
    /**
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "isReady",
    value: function isReady() {
      return exec('isInterstitialReady', []);
    }
  }]);

  return Interstitial;
}();

_defineProperty(Interstitial, "events", events$1);

/**
 * Reward Video config object.
 * @typedef {BaseConfig} RewardVideoConfig
 */

var events$2 = buildEvents('rewardvideo', ['LOAD', 'LOAD_FAIL', 'OPEN', 'CLOSE', 'EXIT_APP', 'START', 'REWARD']);
/**
 * See usage in {@link rewardvideo}.
 * @protected
 */

var RewardVideo = /*#__PURE__*/function () {
  /**
   * @protected
   * @param {RewardVideoConfig} opts - Initial config.
   */
  function RewardVideo(opts) {
    _classCallCheck(this, RewardVideo);

    this.config(_objectSpread2({}, opts));
  }
  /**
   * Update config.
   *
   * @param {RewardVideoConfig} opts - New config.
   * @returns {RewardVideoConfig} Updated config.
   */


  _createClass(RewardVideo, [{
    key: "config",
    value: function config(opts) {
      this._config = _objectSpread2(_objectSpread2({}, this._config), opts);
      return this._config;
    }
    /**
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "prepare",
    value: function prepare() {
      var options = _objectSpread2({
        rewardVideoId: this._config.id
      }, this._config);

      delete options.id;
      return exec('createRewardVideo', [translateOptions(options)]);
    }
    /**
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "show",
    value: function show() {
      return exec('showRewardVideo', [true]);
    }
    /**
     * @returns {Promise} Excutaion result promise.
     */

  }, {
    key: "isReady",
    value: function isReady() {
      return exec('isRewardVideoReady', []);
    }
  }]);

  return RewardVideo;
}();

_defineProperty(RewardVideo, "events", events$2);

/**
 * @type {Banner}
 * @since 0.6
 * @emits {admob.banner.events.LOAD}
 * @emits {admob.banner.events.LOAD_FAIL}
 * @emits {admob.banner.events.OPEN}
 * @emits {admob.banner.events.CLOSE}
 * @example
 * admob.banner.config({
 *  id: 'ca-app-pub-xxx/xxx',
 * })
 *
 * // Create banner
 * admob.banner.prepare()
 *
 * // Show the banner
 * admob.banner.show()
 *
 * // Hide the banner
 * admob.banner.hide()
 *
 * // Remove the banner
 * admob.banner.remove()
 */

var banner = new Banner();
/**
 * @type {Interstitial}
 * @since 0.6
 * @emits {admob.interstitial.events.LOAD}
 * @emits {admob.interstitial.events.LOAD_FAIL}
 * @emits {admob.interstitial.events.OPEN}
 * @emits {admob.interstitial.events.CLOSE}
 * @example
 * admob.interstitial.config({
 *  id: 'ca-app-pub-xxx/xxx',
 * })
 *
 * admob.interstitial.prepare()
 *
 * admob.interstitial.show()
 *
 * admob.interstitial.ready()
 */

var interstitial = new Interstitial();
/**
 * Reward video requires mediation SDK to be installed,
 * see {@link cordova-admob-mediation} for list of supported networks.
 * @type {RewardVideo}
 * @since 0.6
 * @emits {admob.rewardvideo.events.LOAD}
 * @emits {admob.rewardvideo.events.LOAD_FAIL}
 * @emits {admob.rewardvideo.events.OPEN}
 * @emits {admob.rewardvideo.events.CLOSE}
 * @emits {admob.rewardvideo.events.EXIT_APP}
 * @emits {admob.rewardvideo.events.START}
 * @emits {admob.rewardvideo.events.REWARD}
 * @example
 * admob.rewardvideo.config({
 *  id: 'ca-app-pub-xxx/xxx',
 * })
 *
 * admob.rewardvideo.prepare()
 *
 * admob.rewardvideo.show()
 */

var rewardvideo = new RewardVideo(); // Old APIs

/**
 * Set options.
 *
 * @deprecated since version 0.6
 * @param {Object} options
 * @param {string} options.publisherId
 * @param {string} options.interstitialAdId
 *
 * @param {boolean} [options.bannerAtTop=false]
 * Set to true, to put banner at top.
 * @param {boolean} [options.overlap=true]
 * Set to true, to allow banner overlap webview.
 * @param {boolean} [options.offsetTopBar=false]
 * Set to true to avoid ios7 status bar overlap.
 * @param {boolean} [options.isTesting=false]
 * Receiving test ad.
 * @param {boolean} [options.autoShow=true]
 * Auto show interstitial ad when loaded.
 *
 * @param {boolean|null} [options.forChild=null]
 * Default is not calling `tagForChildDirectedTreatment`.
 * Set to "true" for `tagForChildDirectedTreatment(true)`.
 * Set to "false" for `tagForChildDirectedTreatment(false)`.
 *
 * @param {boolean|null} [options.forFamily=null]
 * Android-only.
 * Default is not calling `setIsDesignedForFamilies`.
 * Set to "true" for `setIsDesignedForFamilies(true)`.
 * Set to "false" for `setIsDesignedForFamilies(false)`.
 *
 * @param {function()} [successCallback]
 * @param {function()} [failureCallback]
 */

function setOptions(options, successCallback, failureCallback) {
  if (_typeof(options) === 'object') {
    Object.keys(options).forEach(function (k) {
      switch (k) {
        case 'publisherId':
          banner._config.id = options[k];
          break;

        case 'bannerAtTop':
        case 'overlap':
        case 'offsetTopBar':
          banner._config[k] = options[k];
          break;

        case 'interstitialAdId':
          interstitial._config.id = options[k];
          break;

        case 'rewardVideoId':
          rewardvideo._config.id = options[k];
          break;

        case 'isTesting':
        case 'autoShow':
          banner._config[k] = options[k];
          interstitial._config[k] = options[k];
          rewardvideo._config[k] = options[k];
          break;
      }
    });
    exec$1(successCallback, failureCallback, 'AdMob', 'setOptions', [translateOptions(options)]);
  } else if (typeof failureCallback === 'function') {
    failureCallback('options should be specified.');
  }
}
/**
 * Ad sizes.
 * @constant
 * @type {BANNER_SIZE}
 * @deprecated since version 0.6
 */

var AD_SIZE = Banner.sizes;
/**
 * @deprecated since version 3.1
 */

function userMessagingPlatform() {
  return new Promise(function (resolve, reject) {
    exec$1(resolve, reject, 'AdMob', 'userMessagingPlatform', []);
  });
}
/**
 * @deprecated since version 3.1
 */

function getTrackingStatus() {
  return new Promise(function (resolve, reject) {
    exec$1(resolve, reject, 'AdMob', 'getTrackingStatus', []);
  });
}
/**
 * @deprecated since version 3.1
 */

function trackingStatusForm() {
  return new Promise(function (resolve, reject) {
    exec$1(resolve, reject, 'AdMob', 'trackingStatusForm', []);
  });
}

exports.AD_SIZE = AD_SIZE;
exports.banner = banner;
exports.getTrackingStatus = getTrackingStatus;
exports.interstitial = interstitial;
exports.rewardvideo = rewardvideo;
exports.setOptions = setOptions;
exports.trackingStatusForm = trackingStatusForm;
exports.userMessagingPlatform = userMessagingPlatform;
//# sourceMappingURL=admob.js.map

});
